@@ -50,6 +50,18 @@ _STORAGE_LINKS = StorageLink.add_fragment(
     """
 )
 
+_STORAGE_LINK_DEFAULT = StorageLink.add_fragment(
+    """
+    query GetStorageLinkDefault($projectId: ID!) {
+      project: projectById(id: $projectId) {
+        storageLinkDefault {
+          ...StorageLinkFields
+        }
+      }
+    }
+    """
+)
+
 _DATASET_FILES = File.add_fragment(
     """
     query GetProjectFiles(
@@ -74,7 +86,7 @@ AddableEntity = Union[Dataset, Label]
 
 
 class Project(BaseEntity):
-    """ Projects contain datasets, files and annotations. """
+    """Projects contain datasets, files and annotations."""
 
     id: str
     slug: str
@@ -142,8 +154,19 @@ class Project(BaseEntity):
             ),
         )
 
+    def storage_link_default(self) -> StorageLink:
+        return cast(
+            StorageLink,
+            self.client.query_to_class(
+                StorageLink,
+                _STORAGE_LINK_DEFAULT,
+                path="project.storageLinkDefault",
+                params={"projectId": self.id},
+            ),
+        )
+
     def add(self, entity: AddableEntity):
-        """ Add entity to project """
+        """Add entity to project"""
 
         entity.client = self.client
 
